==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/outputs/MsSqlServerProviderInstancePropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Gets or sets the SQL server provider properties.
 * @property dbPassword Gets or sets the database password.
 * @property dbPasswordUri Gets or sets the key vault URI to secret with the database password.
 * @property dbPort Gets or sets the database sql port.
 * @property dbUsername Gets or sets the database user name.
 * @property hostname Gets or sets the SQL server host name.
 * @property providerType The provider type. For example, the value can be SapHana.
 * Expected value is 'MsSqlServer'.
 * @property sapSid Gets or sets the SAP System Identifier
 * @property sslCertificateUri Gets or sets the blob URI to SSL certificate for the SQL Database.
 * @property sslPreference Gets or sets certificate preference if secure communication is enabled.
 */
public data class MsSqlServerProviderInstancePropertiesResponse(
    public val dbPassword: String? = null,
    public val dbPasswordUri: String? = null,
    public val dbPort: String? = null,
    public val dbUsername: String? = null,
    public val hostname: String? = null,
    public val providerType: String,
    public val sapSid: String? = null,
    public val sslCertificateUri: String? = null,
    public val sslPreference: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.workloads.outputs.MsSqlServerProviderInstancePropertiesResponse):
            MsSqlServerProviderInstancePropertiesResponse =
            MsSqlServerProviderInstancePropertiesResponse(
                dbPassword = javaType.dbPassword().map({ args0 -> args0 }).orElse(null),
                dbPasswordUri = javaType.dbPasswordUri().map({ args0 -> args0 }).orElse(null),
                dbPort = javaType.dbPort().map({ args0 -> args0 }).orElse(null),
                dbUsername = javaType.dbUsername().map({ args0 -> args0 }).orElse(null),
                hostname = javaType.hostname().map({ args0 -> args0 }).orElse(null),
                providerType = javaType.providerType(),
                sapSid = javaType.sapSid().map({ args0 -> args0 }).orElse(null),
                sslCertificateUri = javaType.sslCertificateUri().map({ args0 -> args0 }).orElse(null),
                sslPreference = javaType.sslPreference().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/outputs/MsSqlServerProviderInstancePropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Gets or sets the SQL server provider properties.
 * @property dbPassword Gets or sets the database password.
 * @property dbPasswordUri Gets or sets the key vault URI to secret with the database password.
 * @property dbPort Gets or sets the database sql port.
 * @property dbUsername Gets or sets the database user name.
 * @property hostname Gets or sets the SQL server host name.
 * @property providerType The provider type. For example, the value can be SapHana.
 * Expected value is 'MsSqlServer'.
 * @property sapSid Gets or sets the SAP System Identifier
 * @property sslCertificateUri Gets or sets the blob URI to SSL certificate for the SQL Database.
 * @property sslPreference Gets or sets certificate preference if secure communication is enabled.
 */
public data class MsSqlServerProviderInstancePropertiesResponse(
    public val dbPassword: String? = null,
    public val dbPasswordUri: String? = null,
    public val dbPort: String? = null,
    public val dbUsername: String? = null,
    public val hostname: String? = null,
    public val providerType: String,
    public val sapSid: String? = null,
    public val sslCertificateUri: String? = null,
    public val sslPreference: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.workloads.outputs.MsSqlServerProviderInstancePropertiesResponse): MsSqlServerProviderInstancePropertiesResponse =
            MsSqlServerProviderInstancePropertiesResponse(
                dbPassword = javaType.dbPassword().map({ args0 -> args0 }).orElse(null),
                dbPasswordUri = javaType.dbPasswordUri().map({ args0 -> args0 }).orElse(null),
                dbPort = javaType.dbPort().map({ args0 -> args0 }).orElse(null),
                dbUsername = javaType.dbUsername().map({ args0 -> args0 }).orElse(null),
                hostname = javaType.hostname().map({ args0 -> args0 }).orElse(null),
                providerType = javaType.providerType(),
                sapSid = javaType.sapSid().map({ args0 -> args0 }).orElse(null),
                sslCertificateUri = javaType.sslCertificateUri().map({ args0 -> args0 }).orElse(null),
                sslPreference = javaType.sslPreference().map({ args0 -> args0 }).orElse(null),
            )
    }
}
